<?php
/**
 * Файл для описания класса комбобокса с загрузкой значений из перечисления, 
 * {@link mxl_dict_comboboxenum}.
 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс
 */
/**
 * Класс для хранения информации по комбобоксу с загрузкой значений из 
 * перечисления.
 * Объект класса можно создать только путем загрузки из json-файла, которая 
 * осуществляется функцией {@link mxl_dict_combobox::loadComboboxFromJSON()}
 * при параметре "type" : "enum" в json файле.
 * Структура json-файла:<br>
 * <code>
 * {
 * "type"          : "enum",
 * "name"          : "имя комбобокса",
 * "valueField"    : "поле со значением комбобокса",
 * "displayField"  : "поле которое будет отображаться",
 * "emptyText"     : "текст который будет показан когда не задано значение",
 * "enumName"      : "имя перечисления на основании которого строится комбобокс",
 * "inputTextMode" : false/true - возможность ввода текста для фильтрации значений,
 * "clearedMode"   : false/true - перевод сомбо в режим работы с кнопкой очистить
 * }
 * </code>
 * 
 * Пример json-файла:
 * <code>
 * {
 * "type"          : "enum",
 * "name"          : "testComboboxEnumYesNo",
 * "valueField"    : "val",
 * "displayField"  : "name",
 * "emptyText"     : "Select val...",
 * "enumName"      : "yesNo",
 * "inputTextMode" : false,
 * "clearedMode"   : false
 * }
 * </code>

 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2009, ООО НПО Метарекс, {@link http://www.metarex.ru www.metarex.ru}
 */
class mxl_dict_comboboxenum extends mxl_dict_combobox{
	/**
	 * Создает экземпляр класса на основе json файла комбобокса с типом 
	 * "type":"enum".
	 * @param $cfg - ассоциированный массив, построеный на основе json файла.
	 * @param $combo - экземпляр комбобокса, который передается из потомков
	 * класса для заполнения свойств текущего класса
	 * @return unknown_type
	 */
	public static function loadComboboxFromCfg($cfg, $combo = ''){
		if (!isset($combo)||($combo == '')) 
			$combo = new mxl_dict_comboboxenum($cfg['name'], $cfg['valueField'], 
					$cfg['displayField'], $cfg['emptyText'], $cfg['enumName']);
		$combo = parent::loadComboboxFromCfg($cfg, $combo);
		return $combo;
	}
	
	/**
	 * Имя перечисления, для получения значений комбобокса.
	 * @var string
	 */
	private $enumName;
	
	/**
	 * Конструктор класса
	 * @param $name - имя комбобокса
	 * @param $valueField - имя ключевого поля
	 * @param $displayField - имя поля со значениями 
	 * @param $emptyText - текст отображаемый, когда не задано значение
	 * @param $enumName - имя перечисления, для получения значений из комбобокса. 
	 * @return mxl_dict_comboboxEnum
	 */
	public function __construct($name, $valueField, $displayField, $emptyText, 
			$enumName){
		parent::__construct($name, $valueField, $displayField, $emptyText);		

		$this->enumName = $enumName;
	}

	/**
	 * Метод возвращающий имя перечисления на основе которого заполняются 
	 * значения комбобокса.
	 * @return string
	 */
	public function getEnumName(){
		return $this->enumName;
	}
	
	/**
	 * Функция получения данных для заполнения комбобокса в формате json и их
	 * передачи на клиентскую часть.
	 * Функция обращается к перечислению с целью получения данных и формирует 
	 * текст ответа в формате json.  
	 * Вывод осуществляется при помощи функции echo.	 
	 */
	public function getJSON(){
		header('text/javascript');
		$vf = $this->getValueField();
		$df = $this->getDisplayField();

		$MDS = mxl_core_metadatas::instance();
		$ENUM = $MDS->getMetaData(mxl_core_metadatas::$enum, $this->getEnumName());
		
		$cnt = 0;
		foreach ($ENUM->getListEnumFields() as $key => $value){
			$isIncludeRow = true;
			if ($this->getQuerySeach())
				$isIncludeRow = (strpos($value, $this->getQuerySeach()) === false) ? false : true; 

			if ($isIncludeRow == true){
				$cnt++;
                $r = array($vf => $key, $df => $value);

                //вызов рендерера для строки
                if ($this->getRenderer()){
                    $r = mxl_dict_renderer::execute_renderer ($this->getRenderer(), 
                            mxl_core_metadatas::instance()->getCurrParams(), $r);
                }

                $rows [] = $r;
			}
		}

		if ($cnt > 0)
			echo '({"total":"'.$cnt.'","rows":'.json_encode($rows).'})';
		else
			echo '({"total":"0", "rows":[]})';	
			
		return true;
	}
	
	/**
	 * Функция обращается к перечислению, с целью получения значения для ключа. 
	 * @param $startValue - ключ для которого необходимо найти значение.
	 * @return string
	 */
	public function getStartDisplay($startValue){
		$MDS = mxl_core_metadatas::instance();
		$ENUM = $MDS->getMetaData(mxl_core_metadatas::$enum, $this->getEnumName());
		
		$enumList = $ENUM->getListEnumFields();
		
		if (isset($enumList[$startValue]))
			return $enumList[$startValue];
		else
			return '';
	}
}

?>