<?php
/**
 * Файл для описания класса Списка с загрузкой значений из перечисления, 
 * {@link mxl_dict_comboboxenum}.
 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2010, ООО НПО Метарекс
 */
/**
 * Класс для хранения информации о "Списке" с загрузкой значений из 
 * перечисления.
 * Объект класса можно создать только путем загрузки из json-файла, которая 
 * осуществляется функцией {@link mxl_dict_listenum::loadListFromJSON()}
 * при параметре "type" : "enum" в json файле.
 * Структура json-файла:<br>
 * <code>
 * {
 * "type"          : "enum",
 * "name"          : "имя Списка",
 * "kind"          : "вид списка itemselector или multiselect",
 *   
 * "title"         : "Заголовок на панели",
 * "fieldLabel"    : "Заголовок перед списком",
 * "clearButton"   : true,//Создавать кнопку сброса отобранных значений
 * 
 * "commonWidth"   : 400,//общая ширина 
 * "elementWidth"  : 120,//ширина элемента, для itemselector - ширина каждого элемента
 * "height"        : 150,//высота
 * 
 * "enumName"      : "имя перечисления на основании которого строится список",
 * "valueField"    : "поле со значением",
 * "displayField"  : "поле которое будет отображаться"
 * }
 * </code>
 * 
 * Пример json-файла:
 * <code>
 * {
 * "type"         : "enum",
 * "name"         : "lst_feesres_enum_itemselector",
 * "kind"         : "itemselector",
 * 
 * "title"        : "Item Selector List",
 * "fieldLabel"   : "Supper<br>Field<br>Label",
 * "clearButton"  : true,
 * 
 * "commonWidth"  : 400,
 * "elementWidth" : 120,
 * "height"       : 150,
 * 
 * "enumName"     : "fees_receive_modes",
 * "valueField"   : "fee_receive_mode",
 * "displayField" : "fee_receive_mode_name"
 * }
 * </code>

 * @package mxl_dict
 * @author merlin <merlin@ersys.ru>
 * @copyright Copyright (c) 2010, ООО НПО Метарекс, {@link http://www.metarex.ru www.metarex.ru}
 */
class mxl_dict_listenum extends mxl_dict_list{
	/**
	 * Создает экземпляр класса на основе json файла списка с типом 
	 * "type":"enum".
	 * @param $cfg - ассоциированный массив, построеный на основе json файла.
	 * @param $list - экземпляр комбобокса, который передается из потомков
	 * класса для заполнения свойств текущего класса
	 * @return mxl_dict_listenum
	 */
	public static function loadListFromCfg($cfg, $list = ''){
		if (!isset($list)||($list == '')) 
			$list = new mxl_dict_listenum($cfg['name'], $cfg['valueField'], 
					$cfg['displayField'], $cfg['enumName']);
		$list = parent::loadListFromCfg($cfg, $list);
		return $list;
	}
	
	/**
	 * Имя перечисления, для получения значений списка.
	 * @var string
	 */
	private $enumName;
	
	/**
	 * Конструктор класса списка на основе перечисления.
	 * @param string $name - имя списка 
	 * @param string $valueField - имя поля со значением
	 * @param string $displayField - имя поля, которое будет отображаться 
	 * @param string $enumName - имя перечисления
	 */
	public function __construct($name, $valueField, $displayField, $enumName){
		parent::__construct($name, $valueField, $displayField);		

		$this->enumName = $enumName;
	}

	/**
	 * Метод возвращающий имя перечисления на основе которого заполняются 
	 * значения списка.
	 * @return string
	 */
	public function getEnumName(){
		return $this->enumName;
	}
	
	/**
	 * Функция получения данных для заполнения Списка в формате json и их
	 * передачи на клиентскую часть.
	 * Функция обращается к перечислению с целью получения данных и формирует 
	 * текст ответа в формате json.  
	 * Вывод осуществляется при помощи функции echo.	 
	 */
	public function getJSON(){
		header('text/javascript');
		
		$vf = $this->getValueField();
		$df = $this->getDisplayField();

		$MDS = mxl_core_metadatas::instance();
		$ENUM = $MDS->getMetaData(mxl_core_metadatas::$enum, $this->getEnumName());
		
		$cnt = 0;
		foreach ($ENUM->getListEnumFields() as $key => $value){
			$cnt++;
            $r = array($vf => $key, $df => $value);

            //вызов рендерера для строки
            if ($this->getRenderer()){
                $r = mxl_dict_renderer::execute_renderer ($this->getRenderer(), 
                        mxl_core_metadatas::instance()->getCurrParams(), $r);
            }

            $rows [] = $r;
		}

		if ($cnt > 0)
			echo '({"total":"'.$cnt.'","rows":'.json_encode($rows).'})';
		else
			echo '({"total":"0", "rows":[]})';	
			
		return true;
	}
}

?>